@@ -128,9 +128,6 @@ class AssetSerializer(NeedsReviewMixin, HistorySerializerMixin):
     efi = serializers.BooleanField(required=False)
     # Field generated from warranty API
     warranty = WarrantySerializer(required=False)
-    # Timestamps
-    created = serializers.DateTimeField(default=serializers.CreateOnlyDefault(timezone.now))
-    last_updated = serializers.DateTimeField(default=timezone.now)
 
     class Meta(HistorySerializerMixin.Meta):
         abstract = False
@@ -575,6 +572,8 @@ class FirewallAddressSerializer(serializers.Serializer):
     address = serializers.IPAddressField(required=False)
     length = serializers.IntegerField(required=False)
     address_group = serializers.CharField(required=False)
+    fqdn = serializers.CharField(required=False)
+    user_groups = serializers.ListField(child=serializers.CharField(validators=[validate_group_name]), required=False)
 
     def validate_address_group(self, address_group):
         if address_group:
@@ -586,10 +585,11 @@ class FirewallAddressSerializer(serializers.Serializer):
 
     def validate(self, data):
         data = super(FirewallAddressSerializer, self).validate(data)
-        if 'address' not in data and 'address_group' not in data:
-            raise serializers.ValidationError("address or address_group is required")
-        if 'address' in data and 'address_group' in data:
-            raise serializers.ValidationError("only one of address and address_group can be set")
+        address_types = sum([x in data for x in ['address', 'address_group', 'fqdn', 'user_groups']])
+        if address_types == 0:
+            raise serializers.ValidationError("address, address_group, fqdn, or user_groups is required")
+        if address_types > 1:
+            raise serializers.ValidationError("only one of address, address_group, fqdn, and user_groups can be set")
         return data
 
     def resolve(self):
@@ -959,6 +959,7 @@ class LoadBalancerMemberSerializer(serializers.Serializer):
     port = serializers.IntegerField(required=True)
     ratio = serializers.IntegerField(required=False)
     priority = serializers.IntegerField(required=False)
+    group = serializers.CharField(required=False)
 
 class LoadBalancerIRulePoolSerializer(serializers.Serializer):
     name = serializers.CharField(required=True)
@@ -1028,6 +1029,10 @@ class LBURLValidator(URLValidator):
         r'(?:[/?#][^\s]*)?'  # resource path
         r'\Z', re.IGNORECASE)
 
+class LoadBalancerGroupSerializer(serializers.Serializer):
+    name = serializers.CharField(required=True)
+    ratio = serializers.IntegerField(min_value=0, max_value=100, required=True)
+
 class LoadBalancerSerializer(HistorySerializerMixin):
     id = serializers.CharField(required=False)
     cluster = serializers.CharField(required=True)
@@ -1044,6 +1049,7 @@ class LoadBalancerSerializer(HistorySerializerMixin):
     fallback_persistence_profile = serializers.CharField(required=False)
     lb_method = serializers.ChoiceField(choices=LOAD_BALANCING_METHODS, required=False)
     permissions = PermissionsSerializer(required=False)
+    groups = serializers.ListField(child=LoadBalancerGroupSerializer(), required=False)
 
     class Meta(RethinkSerializer.Meta):
         table_name = 'load_balancer'
